# FrodoDocs

Project documentation with Markdown.

---

[![PyPI Version][pypi-v-image]][pypi-v-link]
[![Build Status][travis-image]][travis-link]
[![Windows Build Status][appveyor-image]][appveyor-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Landscale Code Health][landscape-image]][landscape-link]

- View the [Frodo documentation][frododocs].
- Project [release notes][release-notes].
- Visit the [FrodoDocs wiki](https://frodo.ml) for community
  resources, including third party themes and a list of FrodoDocs users.
- IRC channel: `#frododocs` on freenode.

## Code of Conduct

Everyone interacting in the FrodoDocs project's codebases, issue trackers, chat
rooms, and mailing lists is expected to follow the [PyPA Code of Conduct].

[pypi-v-link]: https://pypi.org/project/FrodoDocs/

[maeguias]: https://frodo.ml
[release-notes]: https://frodo.ml

[PyPA Code of Conduct]: https://www.pypa.io/en/latest/code-of-conduct/
